Class: Google::Apis::CloudtraceV2::MessageEvent

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudtrace_v2/classes.rb,
lib/google/apis/cloudtrace_v2/representations.rb,
lib/google/apis/cloudtrace_v2/representations.rb

Overview

An event describing a message sent/received between Spans.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MessageEvent

Returns a new instance of MessageEvent.



243
244
245
# File 'lib/google/apis/cloudtrace_v2/classes.rb', line 243

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#compressed_size_bytesFixnum

Optional. The number of compressed bytes sent or received. If missing, the compressed size is assumed to be the same size as the uncompressed size. Corresponds to the JSON property compressedSizeBytes

Returns:

  • (Fixnum)


224
225
226
# File 'lib/google/apis/cloudtrace_v2/classes.rb', line 224

def compressed_size_bytes
  @compressed_size_bytes
end

#idFixnum

Optional. An identifier for the MessageEvent's message that can be used to match SENT and RECEIVED MessageEvents. Corresponds to the JSON property id

Returns:

  • (Fixnum)


230
231
232
# File 'lib/google/apis/cloudtrace_v2/classes.rb', line 230

def id
  @id
end

#typeString

Optional. Type of MessageEvent. Indicates whether the message was sent or received. Corresponds to the JSON property type

Returns:

  • (String)


236
237
238
# File 'lib/google/apis/cloudtrace_v2/classes.rb', line 236

def type
  @type
end

#uncompressed_size_bytesFixnum

Optional. The number of uncompressed bytes sent or received. Corresponds to the JSON property uncompressedSizeBytes

Returns:

  • (Fixnum)


241
242
243
# File 'lib/google/apis/cloudtrace_v2/classes.rb', line 241

def uncompressed_size_bytes
  @uncompressed_size_bytes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



248
249
250
251
252
253
# File 'lib/google/apis/cloudtrace_v2/classes.rb', line 248

def update!(**args)
  @compressed_size_bytes = args[:compressed_size_bytes] if args.key?(:compressed_size_bytes)
  @id = args[:id] if args.key?(:id)
  @type = args[:type] if args.key?(:type)
  @uncompressed_size_bytes = args[:uncompressed_size_bytes] if args.key?(:uncompressed_size_bytes)
end