Class: Google::Apis::CloudtraceV2::StackFrame
- Inherits:
-
Object
- Object
- Google::Apis::CloudtraceV2::StackFrame
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudtrace_v2/classes.rb,
lib/google/apis/cloudtrace_v2/representations.rb,
lib/google/apis/cloudtrace_v2/representations.rb
Overview
Represents a single stack frame in a stack trace.
Instance Attribute Summary collapse
-
#column_number ⇒ Fixnum
Optional.
-
#file_name ⇒ Google::Apis::CloudtraceV2::TruncatableString
Represents a string that might be shortened to a specified length.
-
#function_name ⇒ Google::Apis::CloudtraceV2::TruncatableString
Represents a string that might be shortened to a specified length.
-
#line_number ⇒ Fixnum
Optional.
-
#load_module ⇒ Google::Apis::CloudtraceV2::Module
Binary module.
-
#original_function_name ⇒ Google::Apis::CloudtraceV2::TruncatableString
Represents a string that might be shortened to a specified length.
-
#source_version ⇒ Google::Apis::CloudtraceV2::TruncatableString
Represents a string that might be shortened to a specified length.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StackFrame
constructor
A new instance of StackFrame.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StackFrame
Returns a new instance of StackFrame.
446 447 448 |
# File 'lib/google/apis/cloudtrace_v2/classes.rb', line 446 def initialize(**args) update!(**args) end |
Instance Attribute Details
#column_number ⇒ Fixnum
Optional. The column number where the function call appears, if available.
This is important in JavaScript because of its anonymous functions.
Corresponds to the JSON property columnNumber
414 415 416 |
# File 'lib/google/apis/cloudtrace_v2/classes.rb', line 414 def column_number @column_number end |
#file_name ⇒ Google::Apis::CloudtraceV2::TruncatableString
Represents a string that might be shortened to a specified length.
Corresponds to the JSON property fileName
419 420 421 |
# File 'lib/google/apis/cloudtrace_v2/classes.rb', line 419 def file_name @file_name end |
#function_name ⇒ Google::Apis::CloudtraceV2::TruncatableString
Represents a string that might be shortened to a specified length.
Corresponds to the JSON property functionName
424 425 426 |
# File 'lib/google/apis/cloudtrace_v2/classes.rb', line 424 def function_name @function_name end |
#line_number ⇒ Fixnum
Optional. The line number in file_name where the function call appears.
Corresponds to the JSON property lineNumber
429 430 431 |
# File 'lib/google/apis/cloudtrace_v2/classes.rb', line 429 def line_number @line_number end |
#load_module ⇒ Google::Apis::CloudtraceV2::Module
Binary module.
Corresponds to the JSON property loadModule
434 435 436 |
# File 'lib/google/apis/cloudtrace_v2/classes.rb', line 434 def load_module @load_module end |
#original_function_name ⇒ Google::Apis::CloudtraceV2::TruncatableString
Represents a string that might be shortened to a specified length.
Corresponds to the JSON property originalFunctionName
439 440 441 |
# File 'lib/google/apis/cloudtrace_v2/classes.rb', line 439 def original_function_name @original_function_name end |
#source_version ⇒ Google::Apis::CloudtraceV2::TruncatableString
Represents a string that might be shortened to a specified length.
Corresponds to the JSON property sourceVersion
444 445 446 |
# File 'lib/google/apis/cloudtrace_v2/classes.rb', line 444 def source_version @source_version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
451 452 453 454 455 456 457 458 459 |
# File 'lib/google/apis/cloudtrace_v2/classes.rb', line 451 def update!(**args) @column_number = args[:column_number] if args.key?(:column_number) @file_name = args[:file_name] if args.key?(:file_name) @function_name = args[:function_name] if args.key?(:function_name) @line_number = args[:line_number] if args.key?(:line_number) @load_module = args[:load_module] if args.key?(:load_module) @original_function_name = args[:original_function_name] if args.key?(:original_function_name) @source_version = args[:source_version] if args.key?(:source_version) end |