Class: Google::Apis::CloudtraceV2::StackTrace
- Inherits:
-
Object
- Object
- Google::Apis::CloudtraceV2::StackTrace
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudtrace_v2/classes.rb,
lib/google/apis/cloudtrace_v2/representations.rb,
lib/google/apis/cloudtrace_v2/representations.rb
Overview
A call stack appearing in a trace.
Instance Attribute Summary collapse
-
#stack_frames ⇒ Google::Apis::CloudtraceV2::StackFrames
A collection of stack frames, which can be truncated.
-
#stack_trace_hash_id ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StackTrace
constructor
A new instance of StackTrace.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StackTrace
Returns a new instance of StackTrace.
507 508 509 |
# File 'lib/google/apis/cloudtrace_v2/classes.rb', line 507 def initialize(**args) update!(**args) end |
Instance Attribute Details
#stack_frames ⇒ Google::Apis::CloudtraceV2::StackFrames
A collection of stack frames, which can be truncated.
Corresponds to the JSON property stackFrames
495 496 497 |
# File 'lib/google/apis/cloudtrace_v2/classes.rb', line 495 def stack_frames @stack_frames end |
#stack_trace_hash_id ⇒ Fixnum
Optional. The hash ID is used to conserve network bandwidth for duplicate
stack traces within a single trace. Often multiple spans will have identical
stack traces. The first occurrence of a stack trace should contain both the
stackFrame content and a value in stackTraceHashId. Subsequent spans within
the same request can refer to that stack trace by only setting
stackTraceHashId.
Corresponds to the JSON property stackTraceHashId
505 506 507 |
# File 'lib/google/apis/cloudtrace_v2/classes.rb', line 505 def stack_trace_hash_id @stack_trace_hash_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
512 513 514 515 |
# File 'lib/google/apis/cloudtrace_v2/classes.rb', line 512 def update!(**args) @stack_frames = args[:stack_frames] if args.key?(:stack_frames) @stack_trace_hash_id = args[:stack_trace_hash_id] if args.key?(:stack_trace_hash_id) end |