Class: Google::Apis::CloudtraceV2::TimeEvents

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudtrace_v2/classes.rb,
lib/google/apis/cloudtrace_v2/representations.rb,
lib/google/apis/cloudtrace_v2/representations.rb

Overview

A collection of TimeEvents. A TimeEvent is a time-stamped annotation on the span, consisting of either user-supplied key:value pairs, or details of a message sent/received between Spans.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TimeEvents

Returns a new instance of TimeEvents.



611
612
613
# File 'lib/google/apis/cloudtrace_v2/classes.rb', line 611

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dropped_annotations_countFixnum

Optional. The number of dropped annotations in all the included time events. If the value is 0, then no annotations were dropped. Corresponds to the JSON property droppedAnnotationsCount

Returns:

  • (Fixnum)


598
599
600
# File 'lib/google/apis/cloudtrace_v2/classes.rb', line 598

def dropped_annotations_count
  @dropped_annotations_count
end

#dropped_message_events_countFixnum

Optional. The number of dropped message events in all the included time events. If the value is 0, then no message events were dropped. Corresponds to the JSON property droppedMessageEventsCount

Returns:

  • (Fixnum)


604
605
606
# File 'lib/google/apis/cloudtrace_v2/classes.rb', line 604

def dropped_message_events_count
  @dropped_message_events_count
end

#time_eventArray<Google::Apis::CloudtraceV2::TimeEvent>

Optional. A collection of TimeEvents. Corresponds to the JSON property timeEvent



609
610
611
# File 'lib/google/apis/cloudtrace_v2/classes.rb', line 609

def time_event
  @time_event
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



616
617
618
619
620
# File 'lib/google/apis/cloudtrace_v2/classes.rb', line 616

def update!(**args)
  @dropped_annotations_count = args[:dropped_annotations_count] if args.key?(:dropped_annotations_count)
  @dropped_message_events_count = args[:dropped_message_events_count] if args.key?(:dropped_message_events_count)
  @time_event = args[:time_event] if args.key?(:time_event)
end