Class: Google::Apis::CloudtraceV2::TruncatableString

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudtrace_v2/classes.rb,
lib/google/apis/cloudtrace_v2/representations.rb,
lib/google/apis/cloudtrace_v2/representations.rb

Overview

Represents a string that might be shortened to a specified length.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TruncatableString

Returns a new instance of TruncatableString.



642
643
644
# File 'lib/google/apis/cloudtrace_v2/classes.rb', line 642

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#truncated_byte_countFixnum

Optional. The number of bytes removed from the original string. If this value is 0, then the string was not shortened. Corresponds to the JSON property truncatedByteCount

Returns:

  • (Fixnum)


631
632
633
# File 'lib/google/apis/cloudtrace_v2/classes.rb', line 631

def truncated_byte_count
  @truncated_byte_count
end

#valueString

Optional. The shortened string. For example, if the original string is 500 bytes long and the limit of the string is 128 bytes, then value contains the first 128 bytes of the 500-byte string. Truncation always happens on a UTF8 character boundary. If there are multi-byte characters in the string, then the length of the shortened string might be less than the size limit. Corresponds to the JSON property value

Returns:

  • (String)


640
641
642
# File 'lib/google/apis/cloudtrace_v2/classes.rb', line 640

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



647
648
649
650
# File 'lib/google/apis/cloudtrace_v2/classes.rb', line 647

def update!(**args)
  @truncated_byte_count = args[:truncated_byte_count] if args.key?(:truncated_byte_count)
  @value = args[:value] if args.key?(:value)
end